==> nextcloud-31.0.2-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/uk.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Публічне посилання",
    "Photos" : "Світлини",
    "On This Day" : "Цього дня",
    "Your memories under your control" : "Ваші спогади під особистим контролем",
    "All media" : "Усі зображення та відео",
    "Videos" : "Відео",
    "Albums" : "Альбоми",
    "Collaborative albums" : "Спільні альбоми",
    "People" : "Люди",
    "Folders" : "Каталоги",
    "Favorites" : "Із зірочкою",
    "On this day" : "Цього дня",
    "Shared with you" : "Вам надано доступ",
    "Tags" : "Мітки",
    "Places" : "Місця",
    "Map" : "Мапа",
    "Photos settings" : "Налаштування",
    "Mark selection as favorite" : "Позначити вибране як вибране",
    "Add selection to favorites" : "Додайте вибір до вибраного",
    "Remove selection from favorites" : "Вилучити вибір із вибраного",
    "Name of the album" : "Назва альбому",
    "Location of the album" : "Розташування альбому",
    "Back" : "Назад",
    "Add collaborators" : "Додайте співавторів",
    "Save" : "Зберегти",
    "Create album" : "Створити альбом",
    "Add to Album" : "Додати в альбом",
    "Add selection to album {albumName}" : "Додати виділення до альбому {albumName}",
    "Shared by" : "Поділилися",
    "Create a new album." : "Створіть новий альбом.",
    "Create new album" : "Створити новий альбом",
    "New album" : "Новий альбом",
    "_%n item_::_%n photos and videos_" : ["%n фотографії та відео","%n фотографії та відео","%n фотографії та відео","%n фотографії та відео"],
    "Failed to fetch collaborators list." : "Не вдалося отримати список співавторів.",
    "Failed to update album." : "Не вдалося оновити альбом.",
    "Add people or groups who can edit your album" : "Додайте людей або групи, які можуть редагувати ваш альбом",
    "Search people or groups" : "Пошук людей або груп",
    "No recommendations. Start typing." : "Відсутні рекомендації. Будь ласка, додайте.",
    "Group" : "Група",
    "Remove {collaboratorLabel} from the collaborators list" : "Вилучити {collaboratorLabel} зі списку співавторів",
    "Copy the public link" : "Копіювати публічне посилання",
    "Public link copied!" : "Публічне посилання скопійовано!",
    "Copy public link" : "Копіювати публічне посилання",
    "Delete the public link" : "Вилучити публічне посилання",
    "Create public link share" : "Створити посилання спільного доступу",
    "Share via public link" : "Поділіться через публічне посилання",
    "This collection does not exist" : "Ця колекція не існує",
    "An error occurred" : "Виникла помилка",
    "No picture for this day" : "Відсутні зображення цього дня",
    "Picture taken on this day will show up here." : "Зображення, які було отримано цього дня, будуть показані тут.",
    "More photos from this day" : "Більше світлин з цього дня",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n неідентифікована світлина","%n неідентифіковані світлини","%n неідентифікованих світлин","%n неідентифікованих світлин"],
    "Favorite" : "Із зірочкою",
    "Favorite image, open the full size \"{name}\" image" : "Вподобати зображення, відкрити повнорозмірне зображення: \"{name}\"",
    "Open the full size \"{name}\" image" : "Відкрити повнорозмірне зображення: \"{name}\"",
    "Select image {imageName}" : "Виберіть зображення {imageName}",
    "Open the \"{name}\" folder" : "Відкрити каталог \"{name}\"",
    "Back to {folder}" : "Повернутися до каталогу {folder}",
    "Go back" : "Повернутися назад",
    "Share this folder" : "Надати спільний доступ до каталогу",
    "Dates" : "Дати",
    "Jump to specific date in list" : "Перейти до певної дати зі списку",
    "Jump to {date}" : "Перейти до {date}",
    "Add to {destination}" : "Додати до {destination}",
    "The destination folder is owned by {owner}" : "Власником каталогу призначення є {owner}",
    "There are no photos or videos yet!" : "Ще немає фото чи відео!",
    "_{years} year ago_::_{years} years ago_" : ["{years} рік тому","{years} років тому","{years} років тому","{years} років тому"],
    "Enable squared photos view" : "Увімкнути перегляд фотографій у квадраті",
    "Delete source directory" : "Вилучити каталог джерела",
    "Pick folder" : "Вибрати каталог",
    "Select a source folder for your media" : "Виберіть каталог джерела для ваших світлин чи відеозаписів",
    "All folders" : "Усі каталоги",
    "Add a Photos source for the timelines" : "Додати джерело світлин до хронології",
    "Add folder" : "Додати теку",
    "Select the default upload location for your media" : "Виберіть типове розташування для завантаження ваших світлин чи відеозаписів",
    "Home" : "Домівка",
    "Choose default Photos upload and Albums location" : "Виберіть типове розташування для завантаження світлин та альбомів",
    "Choose a different folder" : "Виберіть інший каталог",
    "View" : "Перегляд",
    "Media folders" : "Каталоги з мультимедійним вмістом",
    "Choose the folders from where photos and videos are shown." : "Виберіть каталоги, з яких показувати світлини та відеозаписи.",
    "Upload folder" : "Завантажити каталог",
    "Choose the folder where photos and albums are uploaded to." : "Виберіть каталог, до якого завантажувати світлини та альбоми.",
    "_%n photo_::_%n photos_" : ["%n фото","%n фото","%n фото","%n фото"],
    "Unselect all" : "Зняти вибір",
    "Add photos to this album" : "Додайте фотографії до цього альбому",
    "Manage collaborators for this album" : "Керуйте співавторами для цього альбому",
    "Open actions menu" : "Відкрити меню дій",
    "Edit album details" : "Редагувати деталі альбому",
    "Download all files in album" : "Звантажити всі файли в альбомі",
    "Delete album" : "Вилучити альбом",
    "Download selected files" : "Звантажити вибрані файли",
    "Remove selection from album" : "Вилучити виділення з альбому",
    "This album does not have any photos or videos yet!" : "У цьому альбомі ще немає фото чи відео!",
    "Add photos to {albumName}" : "Додати світлини до {albumName}",
    "Manage collaborators" : "Керуйте співавторами",
    "Save collaborators for this album." : "Зберегти співавторів для цього альбому.",
    "Cover photo for album {albumName}" : "Обкладинка для альбому {albumName}",
    "There is no album yet!" : "Альбоми поки відсутні",
    "This person could not be found" : "Не вдалося знайти людину",
    "Rename person" : "Перейменувати особу",
    "Merge with different person" : "Об'єднати з даними іншої особи",
    "Download selected photos" : "Звантажити вибрані світлини",
    "Remove from favorites" : "Прибрати зірочку",
    "Remove person" : "Вилучити особу",
    "Name of this person" : "Ім'я цієї людини",
    "Save." : "Зберегти.",
    "Merge person" : "Об’єднати особу",
    "Move to different person" : "Перемістити до іншої особи",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Передати фотографії іншому користувачу","Передати фотографії іншим користувачам","Передати фотографії іншим користувачам","Передати фотографії іншим користувачам"],
    "_Remove photo from person_::_Remove photos from person_" : ["Вилучити світлину особи","Вилучити світлини особи","Вилучити світлини особи","Вилучити світлини особи"],
    "This might take some time depending on the size of your photo library." : "Це може зайняти деякий час залежно від розміру вашої бібліотеки фотографій.",
    "Recognized people will show up here" : "Тут відображатимуться розпізнані люди",
    "This folder does not exist" : "Цей каталог не існує",
    "Loading folders …" : "Завантаження папок…",
    "No photos in here" : "Тут немає світлин",
    "Taken on {date} at {time}" : "Зроблено {date} о {time}",
    "This place does not have any photos or videos yet!" : "У цього місця ще немає жодної фотографії чи відео!",
    "Add photos to this place" : "Додайте фотографії до цього місця",
    "Cover photo for place {placeName}" : "Обкладинка для місця {placeName}",
    "There is no place yet!" : "Місця ще немає!",
    "Cover photo for shared album {albumName}." : "Обкладинка для спільного альбому {albumName}.",
    "Back to tags overview" : "Назад до огляду міток",
    "No photos with this tag yet" : "Світлини з такою міткою відсутні",
    "No tags yet" : "Ще немає міток",
    "Photos with tags will show up here" : "Світлини з мітками буде показано тут",
    "Popular tags" : "Популярні мітки",
    "All tags" : "Всі мітки",
    "One of the source folders does not exist" : "Один із каталогів призначення відсутній",
    "Add to album" : "Додати в альбом",
    "Delete selection" : "Вилучити виділення",
    "No photos or videos in here" : "Тут немає фотографій та відео",
    "Unassigned faces" : "Неідентифіковані обличчя",
    "_%n photos_::_%n photos_" : ["%n фото","%n фотографії","%n фотографії","%n фотографії"],
    "Failed to fetch collection." : "Не вдалося отримати колекцію.",
    "Failed to fetch collections list." : "Не вдалося отримати список колекцій.",
    "Failed to fetch faces list." : "Не вдалося отримати список зображень облич.",
    "All your media" : "Усі ваші зображення та відео",
    "Album {title}" : "Альбом {title}",
    "Shared Albums" : "Спільні альбоми",
    "Shared album {title}" : "Спільний альбом {title}",
    "Public album {title}" : "Публічний альбом {title}",
    "Tagged photos" : "Світлини з мітками",
    "Tagged photo {title}" : "Світлина з міткою {title}",
    "{title}'s face" : "обличчя {title}",
    "{startDate} to {endDate}" : "{startDate} до {endDate}",
    "Details" : "Деталі",
    "Failed to rename {oldName} to {faceName}." : "Не вдалося перейменувати {oldName} на {faceName}.",
    "Failed to delete {faceName}." : "Не вдалося вилучити {faceName}.",
    "Failed to delete {fileId}." : "Не вдалося вилучити {fileId}.",
    "Failed to delete {fileName}." : "Не вдалося вилучити {fileName}.",
    "Failed to set favorite state for {fileId}." : "Не вдалося позначити зірочкою {fileId}.",
    "Failed to set favorite state for {fileName}." : "Не вдалося позначити зірочкою {fileName}.",
    "Could not load photos folder" : "Неможливо завантажити каталог зі світлинами",
    "One of the source folders does not exists" : "Один з каталогів джерел відсутній",
    "Add" : "Додати"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/uk.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Публічне посилання",
    "Photos" : "Світлини",
    "On This Day" : "Цього дня",
    "Your memories under your control" : "Ваші спогади під особистим контролем",
    "All media" : "Усі зображення та відео",
    "Videos" : "Відео",
    "Albums" : "Альбоми",
    "Collaborative albums" : "Спільні альбоми",
    "People" : "Люди",
    "Folders" : "Каталоги",
    "Favorites" : "Із зірочкою",
    "On this day" : "Цього дня",
    "Shared with you" : "Вам надано доступ",
    "Tags" : "Мітки",
    "Places" : "Місця",
    "Map" : "Мапа",
    "Photos settings" : "Налаштування",
    "Mark selection as favorite" : "Позначити вибране як вибране",
    "Add selection to favorites" : "Додайте вибір до вибраного",
    "Remove selection from favorites" : "Вилучити вибір із вибраного",
    "Name of the album" : "Назва альбому",
    "Location of the album" : "Розташування альбому",
    "Back" : "Назад",
    "Add collaborators" : "Додайте співавторів",
    "Save" : "Зберегти",
    "Create album" : "Створити альбом",
    "Add to Album" : "Додати в альбом",
    "Add selection to album {albumName}" : "Додати виділення до альбому {albumName}",
    "Shared by" : "Поділилися",
    "Create a new album." : "Створіть новий альбом.",
    "Create new album" : "Створити новий альбом",
    "New album" : "Новий альбом",
    "_%n item_::_%n photos and videos_" : ["%n фотографії та відео","%n фотографії та відео","%n фотографії та відео","%n фотографії та відео"],
    "Failed to fetch collaborators list." : "Не вдалося отримати список співавторів.",
    "Failed to update album." : "Не вдалося оновити альбом.",
    "Add people or groups who can edit your album" : "Додайте людей або групи, які можуть редагувати ваш альбом",
    "Search people or groups" : "Пошук людей або груп",
    "No recommendations. Start typing." : "Відсутні рекомендації. Будь ласка, додайте.",
    "Group" : "Група",
    "Remove {collaboratorLabel} from the collaborators list" : "Вилучити {collaboratorLabel} зі списку співавторів",
    "Copy the public link" : "Копіювати публічне посилання",
    "Public link copied!" : "Публічне посилання скопійовано!",
    "Copy public link" : "Копіювати публічне посилання",
    "Delete the public link" : "Вилучити публічне посилання",
    "Create public link share" : "Створити посилання спільного доступу",
    "Share via public link" : "Поділіться через публічне посилання",
    "This collection does not exist" : "Ця колекція не існує",
    "An error occurred" : "Виникла помилка",
    "No picture for this day" : "Відсутні зображення цього дня",
    "Picture taken on this day will show up here." : "Зображення, які було отримано цього дня, будуть показані тут.",
    "More photos from this day" : "Більше світлин з цього дня",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n неідентифікована світлина","%n неідентифіковані світлини","%n неідентифікованих світлин","%n неідентифікованих світлин"],
    "Favorite" : "Із зірочкою",
    "Favorite image, open the full size \"{name}\" image" : "Вподобати зображення, відкрити повнорозмірне зображення: \"{name}\"",
    "Open the full size \"{name}\" image" : "Відкрити повнорозмірне зображення: \"{name}\"",
    "Select image {imageName}" : "Виберіть зображення {imageName}",
    "Open the \"{name}\" folder" : "Відкрити каталог \"{name}\"",
    "Back to {folder}" : "Повернутися до каталогу {folder}",
    "Go back" : "Повернутися назад",
    "Share this folder" : "Надати спільний доступ до каталогу",
    "Dates" : "Дати",
    "Jump to specific date in list" : "Перейти до певної дати зі списку",
    "Jump to {date}" : "Перейти до {date}",
    "Add to {destination}" : "Додати до {destination}",
    "The destination folder is owned by {owner}" : "Власником каталогу призначення є {owner}",
    "There are no photos or videos yet!" : "Ще немає фото чи відео!",
    "_{years} year ago_::_{years} years ago_" : ["{years} рік тому","{years} років тому","{years} років тому","{years} років тому"],
    "Enable squared photos view" : "Увімкнути перегляд фотографій у квадраті",
    "Delete source directory" : "Вилучити каталог джерела",
    "Pick folder" : "Вибрати каталог",
    "Select a source folder for your media" : "Виберіть каталог джерела для ваших світлин чи відеозаписів",
    "All folders" : "Усі каталоги",
    "Add a Photos source for the timelines" : "Додати джерело світлин до хронології",
    "Add folder" : "Додати теку",
    "Select the default upload location for your media" : "Виберіть типове розташування для завантаження ваших світлин чи відеозаписів",
    "Home" : "Домівка",
    "Choose default Photos upload and Albums location" : "Виберіть типове розташування для завантаження світлин та альбомів",
    "Choose a different folder" : "Виберіть інший каталог",
    "View" : "Перегляд",
    "Media folders" : "Каталоги з мультимедійним вмістом",
    "Choose the folders from where photos and videos are shown." : "Виберіть каталоги, з яких показувати світлини та відеозаписи.",
    "Upload folder" : "Завантажити каталог",
    "Choose the folder where photos and albums are uploaded to." : "Виберіть каталог, до якого завантажувати світлини та альбоми.",
    "_%n photo_::_%n photos_" : ["%n фото","%n фото","%n фото","%n фото"],
    "Unselect all" : "Зняти вибір",
    "Add photos to this album" : "Додайте фотографії до цього альбому",
    "Manage collaborators for this album" : "Керуйте співавторами для цього альбому",
    "Open actions menu" : "Відкрити меню дій",
    "Edit album details" : "Редагувати деталі альбому",
    "Download all files in album" : "Звантажити всі файли в альбомі",
    "Delete album" : "Вилучити альбом",
    "Download selected files" : "Звантажити вибрані файли",
    "Remove selection from album" : "Вилучити виділення з альбому",
    "This album does not have any photos or videos yet!" : "У цьому альбомі ще немає фото чи відео!",
    "Add photos to {albumName}" : "Додати світлини до {albumName}",
    "Manage collaborators" : "Керуйте співавторами",
    "Save collaborators for this album." : "Зберегти співавторів для цього альбому.",
    "Cover photo for album {albumName}" : "Обкладинка для альбому {albumName}",
    "There is no album yet!" : "Альбоми поки відсутні",
    "This person could not be found" : "Не вдалося знайти людину",
    "Rename person" : "Перейменувати особу",
    "Merge with different person" : "Об'єднати з даними іншої особи",
    "Download selected photos" : "Звантажити вибрані світлини",
    "Remove from favorites" : "Прибрати зірочку",
    "Remove person" : "Вилучити особу",
    "Name of this person" : "Ім'я цієї людини",
    "Save." : "Зберегти.",
    "Merge person" : "Об’єднати особу",
    "Move to different person" : "Перемістити до іншої особи",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Передати фотографії іншому користувачу","Передати фотографії іншим користувачам","Передати фотографії іншим користувачам","Передати фотографії іншим користувачам"],
    "_Remove photo from person_::_Remove photos from person_" : ["Вилучити світлину особи","Вилучити світлини особи","Вилучити світлини особи","Вилучити світлини особи"],
    "This might take some time depending on the size of your photo library." : "Це може зайняти деякий час залежно від розміру вашої бібліотеки фотографій.",
    "Recognized people will show up here" : "Тут відображатимуться розпізнані люди",
    "This folder does not exist" : "Цей каталог не існує",
    "Loading folders …" : "Завантаження папок…",
    "No photos in here" : "Тут немає світлин",
    "Taken on {date} at {time}" : "Зроблено {date} о {time}",
    "This place does not have any photos or videos yet!" : "У цього місця ще немає жодної фотографії чи відео!",
    "Add photos to this place" : "Додайте фотографії до цього місця",
    "Cover photo for place {placeName}" : "Обкладинка для місця {placeName}",
    "There is no place yet!" : "Місця ще немає!",
    "Cover photo for shared album {albumName}" : "Обкладинка для спільного альбому {albumName}",
    "Back to tags overview" : "Назад до огляду міток",
    "No photos with this tag yet" : "Світлини з такою міткою відсутні",
    "No tags yet" : "Ще немає міток",
    "Photos with tags will show up here" : "Світлини з мітками буде показано тут",
    "Popular tags" : "Популярні мітки",
    "All tags" : "Всі мітки",
    "One of the source folders does not exist" : "Один із каталогів призначення відсутній",
    "Add to album" : "Додати в альбом",
    "Delete selection" : "Вилучити виділення",
    "No photos or videos in here" : "Тут немає фотографій та відео",
    "Unassigned faces" : "Неідентифіковані обличчя",
    "_%n photos_::_%n photos_" : ["%n фото","%n фотографії","%n фотографії","%n фотографії"],
    "Failed to fetch collection." : "Не вдалося отримати колекцію.",
    "Failed to fetch collections list." : "Не вдалося отримати список колекцій.",
    "Failed to fetch faces list." : "Не вдалося отримати список зображень облич.",
    "All your media" : "Усі ваші зображення та відео",
    "Album {title}" : "Альбом {title}",
    "Shared Albums" : "Спільні альбоми",
    "Shared album {title}" : "Спільний альбом {title}",
    "Public album {title}" : "Публічний альбом {title}",
    "Tagged photos" : "Світлини з мітками",
    "Tagged photo {title}" : "Світлина з міткою {title}",
    "{title}'s face" : "обличчя {title}",
    "{startDate} to {endDate}" : "{startDate} до {endDate}",
    "Details" : "Деталі",
    "Failed to rename {oldName} to {faceName}" : "Не вдалося перейменувати {oldName} у {faceName}",
    "Failed to delete {faceName}" : "Не вдалося вилучити {faceName}",
    "Failed to delete {fileId}" : "Не вдалося вилучити {fileId}",
    "Failed to delete {fileName}" : "Не вдалося вилучити {fileName}",
    "Failed to set favorite state for {fileId}" : "Не вдалося додати зірочку до {fileId}",
    "Failed to set favorite state for {fileName}" : "Не вдалося додати зірочку до {fileName}",
    "Could not load photos folder" : "Неможливо завантажити каталог зі світлинами",
    "One of the source folders does not exists" : "Один з каталогів джерел відсутній",
    "Add" : "Додати"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
